"use client";
import { useState } from "react";
import DataTable from "@/components/tables/DataTable";
import { TableData } from "@/variables/columnsData";
import { DeleteIcon, ViewIcon } from "@chakra-ui/icons";
import { Flex, Button, Icon, useColorModeValue } from "@chakra-ui/react";
import useShowToast from "@/app/hooks/useShowToast";
import { useRouter } from "next/navigation";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";
import { deleteKyc, getKycs } from "@/app/lib/kyc/action";
import { columnsDataKYC } from "../variables/columns";
import Filters from "@/components/filters/Filters";
import { MultiSelectOption } from "@/components/fields/MultiSelect";
import { extractPagination } from "@/utils/common";

interface KYCTableProps {
  data: { data: TableData[] };
  users: MultiSelectOption[];
  ibcs: MultiSelectOption[];
}

const KYCTable: React.FC<KYCTableProps> = ({ data, users, ibcs }) => {
  const { currentUser } = useGeneral();
  const router = useRouter();
  const brandColor = useColorModeValue("brand.500", "white");
  const showToast = useShowToast();
  const [loading, setLoading] = useState<number | null>(null);

  const paginationData = extractPagination(data);

  const handleDelete = async (id: number) => {
    setLoading(id);
    try {
      const response = await deleteKyc(id);
      if (response.status === false) {
        throw new Error(response.message || "Failed to delete KYC record.");
      }
      showToast("KYC Deleted!", response.message, "success");
      router.refresh();
    } catch (error: any) {
      showToast("Failed to delete", error.message, "error");
    } finally {
      setLoading(null);
    }
  };

  const handleView = async (id: number) => {
    router.push(`/admin/attempt/kyc/view/${id}`);
  };

  const actions = (id: number) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "kyc", "view") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => handleView(id)}
          isDisabled={!hasPermission(currentUser.permissions, "kyc", "view")}
        >
          <Icon as={ViewIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}
      {hasPermission(currentUser.permissions, "kyc", "delete") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => handleDelete(id)}
          isDisabled={
            loading === id ||
            !hasPermission(currentUser.permissions, "kyc", "delete")
          }
        >
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}
    </Flex>
  );

  return (
    <DataTable
      columnsData={columnsDataKYC}
      tableData={data?.data as TableData[]}
      paginate={paginationData}
      isSelectable={false}
      showPageSize={false}
      showSearch={false}
      actionSlot={actions}
      filterSlot={
        <Filters
          onExport={getKycs}
          users={users}
          ibcs={ibcs}
          searchLabel="Full Name"
          showBatches={false}
        />
      }
    />
  );
};

export default KYCTable;
